import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import {
  GraduationCap,
  CheckCircle,
  ArrowRight,
  Clock,
  Star,
  Shield,
  Crown,
  Calculator,
  FileText,
  Award,
} from "lucide-react"

export default function PricingPage() {
  const pricingTiers = [
    {
      name: "High School",
      description: "Perfect for high school assignments and projects",
      basePrice: 10,
      multiplier: 1.0,
      icon: <FileText className="h-8 w-8" />,
      color: "from-blue-600 to-blue-700",
      popular: false,
      features: [
        "High school level writing",
        "Basic research and citations",
        "Standard formatting (MLA, APA)",
        "Free revisions",
        "24/7 customer support",
        "Plagiarism-free guarantee",
      ],
    },
    {
      name: "Undergraduate",
      description: "Ideal for college and university students",
      basePrice: 10,
      multiplier: 1.3,
      icon: <GraduationCap className="h-8 w-8" />,
      color: "from-emerald-600 to-emerald-700",
      popular: true,
      features: [
        "University level writing",
        "Advanced research methods",
        "Multiple citation styles",
        "Free revisions",
        "Priority customer support",
        "Quality assurance review",
        "Direct writer communication",
      ],
    },
    {
      name: "Master's",
      description: "Advanced writing for graduate students",
      basePrice: 10,
      multiplier: 1.6,
      icon: <Award className="h-8 w-8" />,
      color: "from-amber-600 to-amber-700",
      popular: false,
      features: [
        "Graduate level expertise",
        "Comprehensive literature review",
        "Advanced analytical writing",
        "Statistical analysis support",
        "Free revisions",
        "Premium writer assignment",
        "Research methodology guidance",
        "Thesis/dissertation support",
      ],
    },
    {
      name: "PhD",
      description: "Expert-level writing for doctoral research",
      basePrice: 10,
      multiplier: 2.2,
      icon: <Crown className="h-8 w-8" />,
      color: "from-purple-600 to-purple-700",
      popular: false,
      features: [
        "Doctoral level expertise",
        "Original research contribution",
        "Advanced statistical analysis",
        "Peer-review quality writing",
        "Free revisions",
        "PhD writer assignment",
        "Research proposal support",
        "Publication-ready quality",
        "Methodology consultation",
      ],
    },
  ]

  const urgencyPricing = [
    { deadline: "14+ days", multiplier: 1.0, description: "Standard delivery" },
    { deadline: "7-13 days", multiplier: 1.2, description: "Moderate urgency" },
    { deadline: "3-6 days", multiplier: 1.4, description: "High priority" },
    { deadline: "1-2 days", multiplier: 1.8, description: "Rush order" },
    { deadline: "12-24 hours", multiplier: 2.5, description: "Emergency delivery" },
  ]

  const additionalServices = [
    {
      name: "Abstract Writing",
      price: "$25",
      description: "Professional abstract for your research paper",
    },
    {
      name: "PowerPoint Presentation",
      price: "$15/slide",
      description: "Comprehensive presentation based on your paper",
    },
    {
      name: "Plagiarism Report",
      price: "$10",
      description: "Detailed plagiarism check with Turnitin report",
    },
    {
      name: "VIP Support",
      price: "$20",
      description: "Priority customer service and faster response times",
    },
    {
      name: "Progressive Delivery",
      price: "$30",
      description: "Receive your work in parts as it's completed",
    },
    {
      name: "Editor's Check",
      price: "$25",
      description: "Additional proofreading by our senior editors",
    },
  ]

  const calculatePrice = (pages: number, level: string, urgency: string) => {
    const basePrice = 10
    const levelMultipliers = {
      "High School": 1.0,
      Undergraduate: 1.3,
      "Master's": 1.6,
      PhD: 2.2,
    }
    const urgencyMultipliers = {
      "14+ days": 1.0,
      "7-13 days": 1.2,
      "3-6 days": 1.4,
      "1-2 days": 1.8,
      "12-24 hours": 2.5,
    }

    const levelMult = levelMultipliers[level as keyof typeof levelMultipliers] || 1.0
    const urgencyMult = urgencyMultipliers[urgency as keyof typeof urgencyMultipliers] || 1.0

    return Math.round(pages * basePrice * levelMult * urgencyMult)
  }

  return (
    <div className="min-h-screen">
      {/* Header */}
      <header className="header-academic">
        <div className="container-academic">
          <div className="flex justify-between items-center py-4">
            <Link href="/" className="flex items-center">
              <div className="w-12 h-12 bg-navy rounded-lg flex items-center justify-center book-spine">
                <GraduationCap className="h-7 w-7 text-white" />
              </div>
              <span className="ml-3 text-2xl font-bold text-navy font-merriweather">ProEssayWorks</span>
            </Link>
            <nav className="hidden md:flex space-x-8">
              <Link href="/" className="nav-academic">
                Home
              </Link>
              <Link href="/services" className="nav-academic">
                Services
              </Link>
              <Link href="/how-it-works" className="nav-academic">
                How It Works
              </Link>
              <Link href="/pricing" className="nav-academic nav-academic-active">
                Pricing
              </Link>
              <Link href="/about" className="nav-academic">
                About
              </Link>
            </nav>
            <div className="flex space-x-3">
              <Link href="/auth/login">
                <Button variant="ghost" className="nav-academic font-medium">
                  Sign In
                </Button>
              </Link>
              <Link href="/auth/register">
                <Button className="btn-academic-primary">Get Started</Button>
              </Link>
            </div>
          </div>
        </div>
      </header>

      {/* Hero Section */}
      <section className="hero-academic section-academic-large">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h1 className="heading-academic-primary text-white">
              Transparent Pricing
              <span className="block bg-gradient-to-r from-yellow-300 to-amber-300 bg-clip-text text-transparent mt-2">
                Quality That Fits Your Budget
              </span>
            </h1>
            <p className="body-academic-large text-white/90">
              Affordable academic writing services with no hidden fees. Choose the level that matches your academic
              requirements and get exceptional quality every time.
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Calculate Your Price
                  <Calculator className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/services">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  View Services
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Pricing Tiers */}
      <section className="section-academic-large paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Academic Level Pricing</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Our pricing is structured by academic level to ensure you receive writing that meets the specific
              requirements and complexity of your educational stage.
            </p>
          </div>

          <div className="grid lg:grid-cols-4 gap-8">
            {pricingTiers.map((tier, index) => (
              <Card
                key={index}
                className={`card-academic relative ${tier.popular ? "ring-2 ring-navy shadow-2xl" : ""}`}
              >
                {tier.popular && (
                  <div className="absolute -top-4 left-1/2 transform -translate-x-1/2">
                    <Badge className="bg-navy text-white px-4 py-1">Most Popular</Badge>
                  </div>
                )}
                <CardHeader className="text-center">
                  <div
                    className={`w-16 h-16 bg-gradient-to-br ${tier.color} rounded-lg flex items-center justify-center mx-auto mb-6 text-white`}
                  >
                    {tier.icon}
                  </div>
                  <CardTitle className="heading-academic-tertiary">{tier.name}</CardTitle>
                  <CardDescription className="body-academic-regular">{tier.description}</CardDescription>
                  <div className="mt-6">
                    <div className="text-4xl font-bold text-navy">${Math.round(tier.basePrice * tier.multiplier)}</div>
                    <div className="text-sm text-gray-cool">per page (275 words)</div>
                  </div>
                </CardHeader>
                <CardContent>
                  <ul className="space-y-3 mb-8">
                    {tier.features.map((feature, featureIndex) => (
                      <li key={featureIndex} className="flex items-center">
                        <CheckCircle className="h-5 w-5 text-emerald-600 mr-3 flex-shrink-0" />
                        <span className="body-academic-small">{feature}</span>
                      </li>
                    ))}
                  </ul>
                  <Link href="/auth/register?role=client">
                    <Button className={`w-full ${tier.popular ? "btn-academic-primary" : "btn-academic-outline"}`}>
                      Order {tier.name} Level
                      <ArrowRight className="ml-2 h-4 w-4" />
                    </Button>
                  </Link>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Urgency Pricing */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Urgency Pricing</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Need your work faster? Our urgency multipliers ensure you can get quality work even with tight deadlines.
            </p>
          </div>

          <div className="grid md:grid-cols-5 gap-6">
            {urgencyPricing.map((urgency, index) => (
              <Card key={index} className="card-academic text-center">
                <CardHeader>
                  <div className="w-12 h-12 bg-gradient-to-br from-navy to-navy-light rounded-lg flex items-center justify-center mx-auto mb-4 text-white">
                    <Clock className="h-6 w-6" />
                  </div>
                  <CardTitle className="text-lg font-bold text-navy">{urgency.deadline}</CardTitle>
                  <CardDescription className="body-academic-small">{urgency.description}</CardDescription>
                </CardHeader>
                <CardContent>
                  <div className="text-2xl font-bold text-navy mb-2">
                    {urgency.multiplier === 1.0 ? "Base Price" : `+${Math.round((urgency.multiplier - 1) * 100)}%`}
                  </div>
                  <div className="text-sm text-gray-cool">{urgency.multiplier}x multiplier</div>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Price Calculator Example */}
      <section className="section-academic paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Pricing Examples</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              See how our pricing works with real examples across different academic levels and deadlines.
            </p>
          </div>

          <div className="grid lg:grid-cols-3 gap-8">
            <Card className="card-academic">
              <CardHeader>
                <CardTitle className="text-xl font-bold text-navy text-center">Standard Order</CardTitle>
              </CardHeader>
              <CardContent className="text-center">
                <div className="space-y-4 mb-6">
                  <div className="flex justify-between">
                    <span>5 pages</span>
                    <span>Undergraduate</span>
                  </div>
                  <div className="flex justify-between">
                    <span>7 days deadline</span>
                    <span>1.2x urgency</span>
                  </div>
                  <div className="border-t pt-4">
                    <div className="text-3xl font-bold text-navy">
                      ${calculatePrice(5, "Undergraduate", "7-13 days")}
                    </div>
                    <div className="text-sm text-gray-cool">Total price</div>
                  </div>
                </div>
                <Link href="/auth/register?role=client">
                  <Button className="w-full btn-academic-primary">Order Now</Button>
                </Link>
              </CardContent>
            </Card>

            <Card className="card-academic ring-2 ring-navy">
              <CardHeader>
                <CardTitle className="text-xl font-bold text-navy text-center">Rush Order</CardTitle>
                <Badge className="bg-navy text-white mx-auto">Popular</Badge>
              </CardHeader>
              <CardContent className="text-center">
                <div className="space-y-4 mb-6">
                  <div className="flex justify-between">
                    <span>3 pages</span>
                    <span>Master's</span>
                  </div>
                  <div className="flex justify-between">
                    <span>2 days deadline</span>
                    <span>1.8x urgency</span>
                  </div>
                  <div className="border-t pt-4">
                    <div className="text-3xl font-bold text-navy">${calculatePrice(3, "Master's", "1-2 days")}</div>
                    <div className="text-sm text-gray-cool">Total price</div>
                  </div>
                </div>
                <Link href="/auth/register?role=client">
                  <Button className="w-full btn-academic-primary">Order Now</Button>
                </Link>
              </CardContent>
            </Card>

            <Card className="card-academic">
              <CardHeader>
                <CardTitle className="text-xl font-bold text-navy text-center">Premium Order</CardTitle>
              </CardHeader>
              <CardContent className="text-center">
                <div className="space-y-4 mb-6">
                  <div className="flex justify-between">
                    <span>10 pages</span>
                    <span>PhD</span>
                  </div>
                  <div className="flex justify-between">
                    <span>14 days deadline</span>
                    <span>1.0x urgency</span>
                  </div>
                  <div className="border-t pt-4">
                    <div className="text-3xl font-bold text-navy">${calculatePrice(10, "PhD", "14+ days")}</div>
                    <div className="text-sm text-gray-cool">Total price</div>
                  </div>
                </div>
                <Link href="/auth/register?role=client">
                  <Button className="w-full btn-academic-primary">Order Now</Button>
                </Link>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Additional Services */}
      <section className="section-academic bg-white">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Additional Services</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Enhance your order with our premium add-on services for a complete academic solution.
            </p>
          </div>

          <div className="grid md:grid-cols-2 lg:grid-cols-3 gap-8">
            {additionalServices.map((service, index) => (
              <Card key={index} className="card-academic">
                <CardHeader>
                  <div className="flex justify-between items-start mb-4">
                    <CardTitle className="text-lg font-bold text-navy">{service.name}</CardTitle>
                    <Badge variant="outline" className="text-navy border-navy">
                      {service.price}
                    </Badge>
                  </div>
                </CardHeader>
                <CardContent>
                  <p className="body-academic-regular text-gray-cool">{service.description}</p>
                </CardContent>
              </Card>
            ))}
          </div>
        </div>
      </section>

      {/* Guarantees */}
      <section className="section-academic paper-texture">
        <div className="container-academic">
          <div className="text-center mb-16">
            <h2 className="heading-academic-secondary mb-8">Our Guarantees</h2>
            <p className="body-academic-large max-w-3xl mx-auto">
              Your satisfaction and academic success are our top priorities. We stand behind our work with comprehensive
              guarantees.
            </p>
          </div>

          <div className="grid md:grid-cols-4 gap-8">
            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-emerald-600 to-emerald-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <Shield className="h-8 w-8" />
                </div>
                <CardTitle className="text-lg font-bold text-navy">Money Back</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  100% refund if you're not satisfied with the quality of your work.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-blue-600 to-blue-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <Clock className="h-8 w-8" />
                </div>
                <CardTitle className="text-lg font-bold text-navy">On-Time Delivery</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  Your work will be delivered on or before the agreed deadline, guaranteed.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-purple-600 to-purple-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <Star className="h-8 w-8" />
                </div>
                <CardTitle className="text-lg font-bold text-navy">Free Revisions</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  Unlimited revisions within 30 days to ensure your complete satisfaction.
                </p>
              </CardContent>
            </Card>

            <Card className="card-academic text-center">
              <CardHeader>
                <div className="w-16 h-16 bg-gradient-to-br from-amber-600 to-amber-700 rounded-lg flex items-center justify-center mx-auto mb-6 text-white">
                  <CheckCircle className="h-8 w-8" />
                </div>
                <CardTitle className="text-lg font-bold text-navy">Plagiarism Free</CardTitle>
              </CardHeader>
              <CardContent>
                <p className="body-academic-regular text-gray-cool">
                  100% original content with comprehensive plagiarism checking and reporting.
                </p>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="section-academic hero-academic">
        <div className="container-academic text-center text-white">
          <div className="max-w-4xl mx-auto space-y-8">
            <h2 className="heading-academic-secondary text-white">Ready to Get Started?</h2>
            <p className="body-academic-large text-white/90">
              Choose your academic level and let our expert writers help you achieve excellence.
            </p>
            <div className="flex flex-col sm:flex-row gap-6 justify-center max-w-lg mx-auto">
              <Link href="/auth/register?role=client">
                <Button className="btn-academic-secondary text-base px-8 py-4 w-full sm:w-auto">
                  Place Your Order
                  <ArrowRight className="ml-2 h-5 w-5" />
                </Button>
              </Link>
              <Link href="/how-it-works">
                <Button
                  variant="outline"
                  className="text-base px-8 py-4 w-full sm:w-auto text-white border-white hover:bg-white hover:text-navy"
                >
                  How It Works
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-navy text-white section-academic">
        <div className="container-academic">
          <div className="grid md:grid-cols-4 gap-10">
            <div className="space-y-8">
              <div className="flex items-center">
                <div className="w-12 h-12 bg-navy-light rounded-lg flex items-center justify-center book-spine">
                  <GraduationCap className="h-7 w-7 text-white" />
                </div>
                <span className="ml-3 text-2xl font-bold font-merriweather">ProEssayWorks</span>
              </div>
              <p className="body-academic-regular text-white/80">
                Empowering academic excellence through distinguished scholarship and expert writing services.
              </p>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Quick Links</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li>
                  <Link href="/" className="hover:text-white transition-colors">
                    Home
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white transition-colors">
                    Services
                  </Link>
                </li>
                <li>
                  <Link href="/how-it-works" className="hover:text-white transition-colors">
                    How It Works
                  </Link>
                </li>
                <li>
                  <Link href="/pricing" className="hover:text-white transition-colors">
                    Pricing
                  </Link>
                </li>
                <li>
                  <Link href="/about" className="hover:text-white transition-colors">
                    About
                  </Link>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Services</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Research Papers</li>
                <li className="hover:text-white transition-colors cursor-pointer">Essays</li>
                <li className="hover:text-white transition-colors cursor-pointer">Dissertations</li>
                <li className="hover:text-white transition-colors cursor-pointer">Case Studies</li>
              </ul>
            </div>
            <div>
              <h3 className="text-xl font-bold mb-8 font-merriweather">Support</h3>
              <ul className="space-y-4 body-academic-regular text-white/80">
                <li className="hover:text-white transition-colors cursor-pointer">Contact Us</li>
                <li className="hover:text-white transition-colors cursor-pointer">FAQ</li>
                <li className="hover:text-white transition-colors cursor-pointer">Privacy Policy</li>
                <li className="hover:text-white transition-colors cursor-pointer">Terms of Service</li>
              </ul>
            </div>
          </div>
          <div className="border-t border-navy-light mt-16 pt-10 text-center">
            <p className="body-academic-regular text-white/70">&copy; 2024 ProEssayWorks. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  )
}
